# Changelog

## [0.26.0](https://github.com/jbussdieker/bussdcc-system/compare/v0.25.0...v0.26.0) (2026-03-23)


### Features

* **notification:** add system notification interface ([108d55a](https://github.com/jbussdieker/bussdcc-system/commit/108d55ab59b24555e49dbd75e923656c4451735b))

## [0.25.0](https://github.com/jbussdieker/bussdcc-system/compare/v0.24.0...v0.25.0) (2026-03-23)


### Features

* **web, deps:** update event handling and dependencies ([c85bb7b](https://github.com/jbussdieker/bussdcc-system/commit/c85bb7b2533a307406afe26b3ff666d9cbbcd386))

## [0.24.0](https://github.com/jbussdieker/bussdcc-system/compare/v0.23.1...v0.24.0) (2026-03-22)


### Features

* **web:** enhance system stats visualization with dynamic colors ([07f8199](https://github.com/jbussdieker/bussdcc-system/commit/07f8199595467e57860abf8060252fc928e37562))

## [0.23.1](https://github.com/jbussdieker/bussdcc-system/compare/v0.23.0...v0.23.1) (2026-03-22)


### Bug Fixes

* **system:** add py.typed file for type checking ([6c6e1be](https://github.com/jbussdieker/bussdcc-system/commit/6c6e1be279916652cc3c72a3f6afccc6b678e39e))

## [0.23.0](https://github.com/jbussdieker/bussdcc-system/compare/v0.22.0...v0.23.0) (2026-03-22)


### Features

* **system:** add web plugin and rename bussdcc-system-health to bussdcc-system ([3c0c1b8](https://github.com/jbussdieker/bussdcc-system/commit/3c0c1b8441ceecbe4ff58875f237096350451bf2))
* **web, interface:** add system stats blueprint and update CPU temperature handling ([a56f86d](https://github.com/jbussdieker/bussdcc-system/commit/a56f86da4b6dfd091a64286210f995569d1f894f))

## [0.22.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.21.0...v0.22.0) (2026-03-22)


### Features

* **web, interface:** enhance CPU monitoring and refactor templates ([ab7bdb7](https://github.com/jbussdieker/bussdcc-system-health/commit/ab7bdb758219091777dc65b716efe5ca298e9905))

## [0.21.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.20.0...v0.21.0) (2026-03-21)


### Features

* **cli, interface:** enhance CLI options and update web interface ([f39a3c5](https://github.com/jbussdieker/bussdcc-system-health/commit/f39a3c555f715eccc3a9b6c61aa4377f726da881))

## [0.20.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.19.0...v0.20.0) (2026-03-16)


### Features

* **web, makefile:** update network event handling and add new make targets ([c5928db](https://github.com/jbussdieker/bussdcc-system-health/commit/c5928dbdf8c27f8b604280d983f99004e8f39b2f))

## [0.19.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.18.1...v0.19.0) (2026-03-11)


### Features

* **dependencies, imports:** update bussdcc-framework and refactor imports ([c305935](https://github.com/jbussdieker/bussdcc-system-health/commit/c305935054b618b3ac91273630462c3b18e037d8))

## [0.18.1](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.18.0...v0.18.1) (2026-03-08)


### Bug Fixes

* **dependencies:** update bussdcc-framework and psutil versions ([694353d](https://github.com/jbussdieker/bussdcc-system-health/commit/694353d721630366a7e42da7ea0af3c5fdfc8df1))

## [0.18.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.17.0...v0.18.0) (2026-03-08)


### Features

* **dependencies:** update bussdcc-framework to v0.16.0 ([8223d66](https://github.com/jbussdieker/bussdcc-system-health/commit/8223d66fc50de5e84071b77a256d7277fa4b70e0))

## [0.17.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.16.0...v0.17.0) (2026-03-07)


### Features

* **dependencies:** update bussdcc-framework to v0.15.0 ([b039725](https://github.com/jbussdieker/bussdcc-system-health/commit/b03972588aa3db7145b595304c88488ceddc3e0c))

## [0.16.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.15.1...v0.16.0) (2026-03-07)


### Features

* **runtime:** update registration methods and dependencies ([d659b2b](https://github.com/jbussdieker/bussdcc-system-health/commit/d659b2b277ccea5874f7a2a1b8f0b6e1bd23e004))


### Bug Fixes

* **dependencies:** update bussdcc-framework to v0.14.1 ([7a61643](https://github.com/jbussdieker/bussdcc-system-health/commit/7a61643c8e874419e9868102bf8028e4cfb5b0fb))

## [0.15.1](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.15.0...v0.15.1) (2026-03-06)


### Bug Fixes

* **dependencies:** update bussdcc-framework to v0.13.1 ([c1d68c0](https://github.com/jbussdieker/bussdcc-system-health/commit/c1d68c0c9b2135a3d9c0c8b8421652b323181747))

## [0.15.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.14.0...v0.15.0) (2026-03-06)


### Features

* **dependencies:** update bussdcc-framework to v0.13.0 ([c8b71cf](https://github.com/jbussdieker/bussdcc-system-health/commit/c8b71cf560f5013f40941839dc4eba2f1f67f239))

## [0.14.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.13.0...v0.14.0) (2026-03-06)


### Features

* **dependencies:** update bussdcc-framework to v0.12.0 ([34c20f7](https://github.com/jbussdieker/bussdcc-system-health/commit/34c20f78acd24237b59fa7e2674c6400d53ea49b))

## [0.13.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.12.0...v0.13.0) (2026-03-05)


### Features

* **cli:** enhance CLI with replay functionality and update dependencies ([1903225](https://github.com/jbussdieker/bussdcc-system-health/commit/1903225e0736f08cf938857a2a0588500e236351))

## [0.12.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.11.0...v0.12.0) (2026-03-04)


### Features

* **system-health:** update dependencies and remove message names ([28dd7cc](https://github.com/jbussdieker/bussdcc-system-health/commit/28dd7ccfc1db87405eeb36347a90ca2527c53b7b))

## [0.11.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.10.0...v0.11.0) (2026-03-04)


### Features

* **dependencies:** update bussdcc-framework to v0.8.0 ([1c45852](https://github.com/jbussdieker/bussdcc-system-health/commit/1c458527003e9844002465c78f1dbb1d0022965e))

## [0.10.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.9.0...v0.10.0) (2026-03-03)


### Features

* **system-health:** enhance immutability and update dependencies ([5dc5907](https://github.com/jbussdieker/bussdcc-system-health/commit/5dc5907edde4d00c36fa2c407c1acf267730659d))

## [0.9.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.8.0...v0.9.0) (2026-03-01)


### Features

* **system-health:** update event handling to use Message instead of EventSchema ([c29727a](https://github.com/jbussdieker/bussdcc-system-health/commit/c29727a6395d2ac24982426b645de6539aa19b72))

## [0.8.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.7.0...v0.8.0) (2026-03-01)


### Features

* **dependencies:** update bussdcc and bussdcc-framework versions ([a289dfe](https://github.com/jbussdieker/bussdcc-system-health/commit/a289dfe590633377c1a65f0f48f59f2a9d509462))

## [0.7.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.6.0...v0.7.0) (2026-03-01)


### Features

* **system-health:** integrate bussdcc-framework and remove deprecated components ([dfb46ef](https://github.com/jbussdieker/bussdcc-system-health/commit/dfb46ef34b6c8e6ad772341c39df78192253c384))

## [0.6.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.5.0...v0.6.0) (2026-02-28)


### Features

* **runtime, events:** refactor event handling and add new event schemas ([7e85ec6](https://github.com/jbussdieker/bussdcc-system-health/commit/7e85ec6918496774d1de94d0de839159363187f0))

## [0.5.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.4.0...v0.5.0) (2026-02-22)


### Features

* **interface, service:** update network chart and remove interval from system identity ([6e4e711](https://github.com/jbussdieker/bussdcc-system-health/commit/6e4e711bf0efdc41e739823a2f060769a19fd038))
* **interface:** enhance web interface with updated scripts and styles ([d4f930d](https://github.com/jbussdieker/bussdcc-system-health/commit/d4f930df80153ec8360ea1a33114e3330e06523e))
* **makefile:** add run target for system health service ([b287da5](https://github.com/jbussdieker/bussdcc-system-health/commit/b287da5c79f156d668acb61895b28a4e4bbd535d))
* **systemd:** add quiet mode to service execution ([fa57e43](https://github.com/jbussdieker/bussdcc-system-health/commit/fa57e43f1ac3cebabe9f295eae08a87c6926b2a7))
* **systemd:** update service to support web options ([6e72207](https://github.com/jbussdieker/bussdcc-system-health/commit/6e72207e868ea7e72e4bdb87b561be58ec2873ae))
* **web, cli:** add configurable web host and port options ([a200aa0](https://github.com/jbussdieker/bussdcc-system-health/commit/a200aa036ffca7fcd24c332b55cab8786192d020))


### Bug Fixes

* **web:** add typing support to web factory ([35ee9e2](https://github.com/jbussdieker/bussdcc-system-health/commit/35ee9e2b71e0b5dbe95c00f2a911097855694d13))


### Documentation

* **readme:** update installation instructions for Linux/Raspberry Pi ([ddcb761](https://github.com/jbussdieker/bussdcc-system-health/commit/ddcb761b128e1cb481fbfd172e87a167da187ac4))

## [0.4.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.3.1...v0.4.0) (2026-02-19)


### Features

* **dependencies:** update bussdcc to version 0.22.0 ([bb7f842](https://github.com/jbussdieker/bussdcc-system-health/commit/bb7f8426ce0798a2fa215b4f09390d44c380d0c1))

## [0.3.1](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.3.0...v0.3.1) (2026-02-18)


### Bug Fixes

* **dependencies:** update bussdcc to version 0.20.1 ([bcecb61](https://github.com/jbussdieker/bussdcc-system-health/commit/bcecb61a459eb553e769bc955764bf717a4d04da))

## [0.3.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.2.0...v0.3.0) (2026-02-18)


### Features

* **cli:** enhance CLI with Click and add new options ([b55205e](https://github.com/jbussdieker/bussdcc-system-health/commit/b55205e54134d2fe58171419a608fb5a1c1032cf))
* **system-health:** enhance system health interface with new UI components ([5d8866c](https://github.com/jbussdieker/bussdcc-system-health/commit/5d8866caeea93b7fe72d416b0778690935e09c23))

## [0.2.0](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.1.1...v0.2.0) (2026-02-18)


### Features

* **dependencies:** update bussdcc to version 0.19.0 ([340c719](https://github.com/jbussdieker/bussdcc-system-health/commit/340c719cfa3452631fdcde3940fce8d1279837b6))

## [0.1.1](https://github.com/jbussdieker/bussdcc-system-health/compare/v0.1.0...v0.1.1) (2026-02-17)


### Documentation

* add MIT license ([5f88729](https://github.com/jbussdieker/bussdcc-system-health/commit/5f887292a0424133b10ed0329a58278fecbe94e3))

## 0.1.0 (2026-02-17)


### Features

* initial commit ([2443ba3](https://github.com/jbussdieker/bussdcc-system-health/commit/2443ba35f44a20db882228f0b3ae57a8c453b6ca))
